montepy.data\_inputs.material\_component module
===============================================


.. automodule:: montepy.data_inputs.material_component
   :members:
   :undoc-members:
   :show-inheritance:
